@@ -6,11 +6,12 @@ from .portal_client import PortalClient
 from .subscription_client import SubscriptionClient
 
 __all__ = [
-    ApiClient,
-    DeviceInfo,
-    DeebotAuthClient,
-    Credentials,
-    DeebotEntity,
-    PortalClient,
-    SubscriptionClient
+    "ApiClient",
+    "DeviceInfo",
+    "DeebotAuthClient",
+    "Credentials",
+    "DeebotEntity",
+    "PortalClient",
+    "SubscriptionClient",
 ]
+__version__ = "1.0.2"
