@@ -1,5 +1,5 @@
 REALM = "ecouser.net"
-USER_AGENT = "Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)",
+USER_AGENT = ("Dalvik/2.1.0 (Linux; U; Android 5.1.1; A5010 Build/LMY48Z)",)
 
 APP_DO_PATH = "appsvr/app.do"
 USER_DO_PATH = "users/user.do"
